# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tradingstrategy',
 'tradingstrategy.analysis',
 'tradingstrategy.environment',
 'tradingstrategy.frameworks',
 'tradingstrategy.transport',
 'tradingstrategy.utils']

package_data = \
{'': ['*'],
 'tradingstrategy': ['chains/*',
                     'chains/.ci/*',
                     'chains/.github/*',
                     'chains/.github/ISSUE_TEMPLATE/*',
                     'chains/.github/workflows/*',
                     'chains/_data/chains/*',
                     'chains/_data/chains/deprecated/*',
                     'chains/_data/icons/*',
                     'chains/gradle/wrapper/*',
                     'chains/src/main/kotlin/org/ethereum/lists/chains/*',
                     'chains/src/main/kotlin/org/ethereum/lists/chains/model/*',
                     'chains/src/test/kotlin/org/ethereum/lists/chains/*',
                     'chains/src/test/resources/test_chains/invalid/*',
                     'chains/src/test/resources/test_chains/invalid/explorerinvalidurl/*',
                     'chains/src/test/resources/test_chains/invalid/explorermissingurl/*',
                     'chains/src/test/resources/test_chains/invalid/explorernoname/*',
                     'chains/src/test/resources/test_chains/invalid/explorersnotarray/*',
                     'chains/src/test/resources/test_chains/invalid/sameshortname/*',
                     'chains/src/test/resources/test_chains/invalid/withparentchaindoesnotexist/*',
                     'chains/src/test/resources/test_chains/invalid/withparentextrabridgeelementnoobject/*',
                     'chains/src/test/resources/test_chains/invalid/withparentextrabridgesfield/*',
                     'chains/src/test/resources/test_chains/invalid/withparentextrabridgesnoarray/*',
                     'chains/src/test/resources/test_chains/invalid/withparentextrafield/*',
                     'chains/src/test/resources/test_chains/invalid/withparentinvalidtype/*',
                     'chains/src/test/resources/test_chains/invalid/withparentnobject/*',
                     'chains/src/test/resources/test_chains/invalid/wrongexplorerstandard/*',
                     'chains/src/test/resources/test_chains/valid/*',
                     'chains/src/test/resources/test_chains/valid/withexplorer/*',
                     'chains/src/test/resources/test_chains/valid/withparent/*',
                     'chains/src/test/resources/test_chains/valid/withparentbridge/*']}

install_requires = \
['chart-studio>=1.1.0,<2.0.0',
 'cufflinks>=0.17.3,<0.18.0',
 'dataclasses-json>=0.5.4,<0.6.0',
 'eth-hash[pycryptodome]>=0.3.1,<0.4.0',
 'eth-utils>=1.10.0,<2.0.0',
 'fastquant>=0.1.5,<0.2.0',
 'mplfinance>=0.12.7-alpha.17,<0.13.0',
 'pandas>=1.3.0,<2.0.0',
 'plotly>=5.1.0,<6.0.0',
 'pyarrow>=4.0.1,<5.0.0',
 'tqdm>=4.61.2,<5.0.0',
 'trading-strategy-backtrader>=0.1,<0.2',
 'trading-strategy-qstrader>=0.3.0,<0.4.0',
 'zstandard>=0.15.2,<0.16.0']

setup_kwargs = {
    'name': 'tradingstrategy',
    'version': '0.2.14',
    'description': 'Trading algorithm and quantitative financial analysis framework for decentralised exchanges and blockchains',
    'long_description': '[![CI Status](https://github.com/tradingstrategy-ai/client/actions/workflows/python-app.yml/badge.svg)](https://github.com/tradingstrategy-ai/client/actions/workflows/python-app.yml)\n\n[![pip installation works](https://github.com/tradingstrategy-ai/client/actions/workflows/pip-install.yml/badge.svg)](https://github.com/tradingstrategy-ai/client/actions/workflows/pip-install.yml)\n\n# Trading Strategy protocol client\n\nTrading Strategy client is a Python library for on-chain algorithmic trading and trading bots. \n\n# Use cases\n\n* Analysing of cryptocurrency investment opportunities\n\n* Creating trading algorithms and bots that operate on on-chain data\n\n# Features\n\n* Getting trading data from on-chain decentralised exchanges like Uniswap and PancakeSwap\n\n* Integration with [Jupyter Notebook](https://jupyter.org/) for easy manipulation of data \n\n* Use Python quant toolkits like [Backtrader](https://tradingstrategy.ai/docs/glossary.html#term-Backtrader) to create, analyse and backtest DEX trading algorithms \n\n* (*soon*) Decentralised execution of trading algorithms through smart contracts\n\n# Example and getting started \n\nSee [the Getting Started notebook](https://tradingstrategy.ai/docs/programming/examples/getting-started.html) and the rest of the [Trading Strategy documentation](https://tradingstrategy.ai/docs/).\n\n## Prerequisites\n\nPython 3.7+\n\n## Adding the package\n\n**Note**: Unless you are an experienced Python developer, [the suggested usage of Trading Algorithm framework is using Google Colab hosted environments](https://tradingstrategy.ai/docs/programming/examples/getting-started.html).\n\nYou can install this package with `pip` or `poetry`\n\n```shell\npip install tradindstrategy \n```\n\n```shell\npoetry add tradindstrategy\n```\n\n# License\n\nGNU AGPL 3.0. \n',
    'author': 'Mikko Ohtamaa',
    'author_email': 'mikko@capitalgram.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://tradingstrategy.ai',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.2,<4.0.0',
}


setup(**setup_kwargs)
